/* Copyright 2016 Dirk Duschinger */

//////////////////////////////////////
// author : Dirk Duschinger         //
// email  : dirk.duschigner@cern.ch //
//////////////////////////////////////

#ifndef INCLUDE_CURSESOUTPUTHANDLER_H_
#define INCLUDE_CURSESOUTPUTHANDLER_H_

#include <panel.h>

#include <string>
#include <iostream>
#include <sstream>

#include "ROOTReader.h"

typedef struct _PANEL_DATA {
  int hide;/* TRUE if panel is hidden */
} PANEL_DATA;

class CursesOutputHandler {
 public:
  ~CursesOutputHandler();
  explicit CursesOutputHandler(ROOTReader* rr);

  void initialize();
  void reinitialize();
  void initcursescolors();


  void CloseHelp();
  void CloseSave();
  int GetCursesXRes();
  // int GetCursesYRes();
  int GetOffsetLeftPanel();
  ROOTPanelEntry* GetPanelEntry(int y);
  ROOTPanelEntry* GetPanelEntry(ROOTPanelEntry* rpe, int* y);
  int* GetPanelHeight();
  WINDOW* GetPadWindow();
  WINDOW* GetPanelWindow();
  // WINDOW* GetDEBUGWindow();
  int GetWidthLeftPanel();
  void OpenHelp();
  char* OpenSave();
  void SetOffsetLeftPanel(int OffsetLeftPanel);
  void SetWidthLeftPanel(int WidthLeftPanel);
  void UpdateScreen();
  void UpdatePanelSelection(int CurserY);
  void WriteHelp();
  void WritePanel();
  void WriteSave();
  void WritePanelRecursive(ROOTPanelEntry* rpe,
                           int& yOffset,
                           int xOffset);
  void DrawFrame();
  void UpdateResolution();

 private:
  PANEL* m_pPanels[6];
  PANEL_DATA m_pPanelsData[6];
  int m_iWidthLeftPanel;
  int m_iCursesXRes;
  int m_iCursesYRes;
  WINDOW* m_wPanel;
  WINDOW* m_wPad;
  WINDOW* m_wHelp;
  WINDOW* m_wSave;
  WINDOW* m_wDEBUG;
  // bool m_bShowHelp;
  // bool m_bShowSave;
  int m_iPanelX;
  int m_iPanelY;
  int m_iPanelOffset;
  int m_iPanelHeight;
  int m_iPanelWidth;
  int m_iPadX;
  int m_iPadY;
  int m_iPadHeight;
  int m_iPadWidth;
  int m_iHelpX;
  int m_iHelpY;
  int m_iHelpHeight;
  int m_iHelpWidth;
  int m_iSaveX;
  int m_iSaveY;
  int m_iSaveHeight;
  int m_iSaveWidth;
  // int m_iPanelSelect;
  int m_iPanelCurserPosition;
  ROOTReader* m_RR;
};

template <typename T> std::string tostr(const T& t) {
  std::ostringstream os;
  os << t;
  return os.str();
}


#endif  // INCLUDE_CURSESOUTPUTHANDLER_H_

